summaryrefslogtreecommitdiffstats
path: root/generic/tclCmdAH.c
diff options
context:
space:
mode:
Diffstat (limited to 'generic/tclCmdAH.c')
-rw-r--r--generic/tclCmdAH.c10
1 files changed, 7 insertions, 3 deletions
diff --git a/generic/tclCmdAH.c b/generic/tclCmdAH.c
index e054c29..abcb083 100644
--- a/generic/tclCmdAH.c
+++ b/generic/tclCmdAH.c
@@ -10,7 +10,7 @@
* See the file "license.terms" for information on usage and redistribution of
* this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tclCmdAH.c,v 1.93 2008/03/14 16:07:23 dgp Exp $
+ * RCS: @(#) $Id: tclCmdAH.c,v 1.93.2.1 2008/07/21 19:38:17 andreas_kupries Exp $
*/
#include "tclInt.h"
@@ -656,11 +656,15 @@ Tcl_EvalObjCmd(
if (objc == 2) {
/*
* TIP #280. Make invoking context available to eval'd script.
*/
+ CmdFrame* invoker = iPtr->cmdFramePtr;
+ int word = 1;
+ TclArgumentGet (interp, objv[1], &invoker, &word);
+
result = TclEvalObjEx(interp, objv[1], TCL_EVAL_DIRECT,
- iPtr->cmdFramePtr, 1);
+ invoker, word);
} else {
/*
* More than one argument: concatenate them together with spaces
@@ -656,11 +656,15 @@ Tcl_EvalObjCmd(
if (objc == 2) {
/*
- * TIP #280. Make invoking context available to eval'd script.
+ * TIP #280. Make argument location available to eval'd script.
*/